@@ -23,39 +23,22 @@ import java.util.List;
  *
  * @author Yusuke Yamamoto - yusuke at mac.com
  */
-public interface QueryResult extends TwitterResponse, java.io.Serializable {
+public interface QueryResult extends java.io.Serializable {
     long getSinceId();
 
     long getMaxId();
 
-    /**
-     * @deprecated use {@link #getRefreshURL()} instead
-     */
     String getRefreshUrl();
 
-    String getRefreshURL();
+    int getResultsPerPage();
 
-    int getCount();
+    String getWarning();
 
     double getCompletedIn();
 
+    int getPage();
+
     String getQuery();
 
-    List<Status> getTweets();
-
-    /**
-     * Returns a Query instance to fetch next page or null if there is no next page.
-     *
-     * @return Query instance to fetch next page
-     * @since Twitter4J 3.0.0
-     */
-    Query nextQuery();
-
-    /**
-     * test if there is next page
-     *
-     * @return if there is next page
-     * @since Twitter4J 3.0.0
-     */
-    boolean hasNext();
+    List<Tweet> getTweets();
 }
