@@ -63,10 +63,8 @@ import com.openexchange.session.Session;
  */
 public class FacebookMessagingResource implements MessagingResource {
 
-    protected static final org.apache.commons.logging.Log LOG =
-        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(FacebookMessagingResource.class));
-
-    protected static final boolean DEBUG = LOG.isDebugEnabled();
+    protected static final org.slf4j.Logger LOG =
+        org.slf4j.LoggerFactory.getLogger(FacebookMessagingResource.class);
 
     /**
      * The messaging account.
