@@ -51,6 +51,7 @@ package com.openexchange.messaging.facebook.parser.stream;
 
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -59,7 +60,6 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -69,7 +69,6 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.html.HtmlService;
 import com.openexchange.java.Strings;
-import com.openexchange.log.LogFactory;
 import com.openexchange.messaging.MessagingExceptionCodes;
 import com.openexchange.messaging.MessagingHeader;
 import com.openexchange.messaging.StringContent;
@@ -176,7 +175,7 @@ public final class FacebookFQLStreamJsonParser {
                     // message.setHeader(MessagingHeader.KnownHeader.FROM.toString(), item.getTextContent());
                     final long fromId = streamInformation.optLong("actor_id", -1L);
                     if (fromId < 0) {
-                        com.openexchange.log.Log.valueOf(LogFactory.getLog(FacebookFQLStreamJsonParser.class)).warn(
+                        org.slf4j.LoggerFactory.getLogger(FacebookFQLStreamJsonParser.class).warn(
                             new StringBuilder("Field actor_id cannot be parsed to a long: ``").append(streamInformation.opt("actor_id")).append("\u00b4\u00b4").toString());
                     }
                     message.setFromId(fromId);
@@ -474,7 +473,7 @@ public final class FacebookFQLStreamJsonParser {
                                 throw e;
                             }
                             // Something went wrong loading URL content... Ignore it
-                            LogFactory.getLog(FacebookFQLStreamJsonParser.class).debug("Couldn't load URL: " + sourceURL, e);
+                            org.slf4j.LoggerFactory.getLogger(FacebookFQLStreamJsonParser.class).debug("Couldn''t load URL: {}", sourceURL, e);
                         }
                     } else {
                         final StringBuilder messageText = message.getMessageText();
@@ -690,7 +689,7 @@ public final class FacebookFQLStreamJsonParser {
                         if ("attachment".equals(name)) {
                             attachmentNode = streamElement.getJSONObject("attachment");
                         } else {
-                            com.openexchange.log.Log.valueOf(LogFactory.getLog(FacebookFQLStreamJsonParser.class)).warn("Un-handled item: " + name);
+                            org.slf4j.LoggerFactory.getLogger(FacebookFQLStreamJsonParser.class).warn("Un-handled item: {}", name);
                         }
                     } else {
                         itemHandler.handleItem(streamElement, message);
@@ -705,7 +704,7 @@ public final class FacebookFQLStreamJsonParser {
                 /*
                  * Empty message... ignore it!
                  */
-                com.openexchange.log.Log.valueOf(LogFactory.getLog(FacebookFQLStreamJsonParser.class)).warn("Empty Facebook message detected:\n" + streamElement);
+                org.slf4j.LoggerFactory.getLogger(FacebookFQLStreamJsonParser.class).warn("Empty Facebook message detected:\n{}", streamElement);
                 return null;
             }
             /*
@@ -722,9 +721,9 @@ public final class FacebookFQLStreamJsonParser {
                     if (!Strings.isEmpty(type)) {
                         final AttachmentHandler attachmentHandler = ATTACH_HANDLERS.get(type);
                         if (null == attachmentHandler) {
-                            final Log logger = com.openexchange.log.Log.valueOf(LogFactory.getLog(FacebookFQLStreamJsonParser.class));
-                            logger.warn("Unknown attachment type: " + type);
-                            logger.debug("Stream element:\n" + streamElement.toString(2));
+                            final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(FacebookFQLStreamJsonParser.class);
+                            logger.warn("Unknown attachment type: {}", type);
+                            logger.debug("Stream element:\n{}", streamElement.toString(2));
                         } else {
                             attachmentHandlerApplied = attachmentHandler.handleAttachment(attachmentNode, message, multipartProvider);
                         }
@@ -740,9 +739,9 @@ public final class FacebookFQLStreamJsonParser {
                             if (null != sType) {
                                 final AttachmentHandler attachmentHandler = ATTACH_HANDLERS.get(sType);
                                 if (null == attachmentHandler) {
-                                    final Log logger = com.openexchange.log.Log.valueOf(LogFactory.getLog(FacebookFQLStreamJsonParser.class));
-                                    logger.warn("Unknown attachment type: " + sType);
-                                    logger.debug("Stream element:\n" + streamElement.toString(2));
+                                    final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(FacebookFQLStreamJsonParser.class);
+                                    logger.warn("Unknown attachment type: {}", sType);
+                                    logger.debug("Stream element:\n{}", streamElement.toString(2));
                                 } else {
                                     attachmentHandlerApplied = attachmentHandler.handleAttachment(attachmentNode, message, multipartProvider);
                                 }
@@ -767,8 +766,8 @@ public final class FacebookFQLStreamJsonParser {
 
                     size = messageText.length();
                 } else {
-                    final Log logger = com.openexchange.log.Log.valueOf(LogFactory.getLog(FacebookFQLStreamJsonParser.class));
-                    logger.debug("Stream element is an empty message:\n" + streamElement.toString(2));
+                    final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(FacebookFQLStreamJsonParser.class);
+                    logger.debug("Stream element is an empty message:\n{}", streamElement.toString(2));
                     return null;
                 }
             }
