@@ -629,7 +629,7 @@ public final class FacebookMessagingUtility {
         int digit;
 
         if (i < max) {
-            digit = Character.digit(s.charAt(i++), RADIX);
+            digit = digit(s.charAt(i++));
             if (digit < 0) {
                 return DEFAULT;
             }
@@ -639,7 +639,7 @@ public final class FacebookMessagingUtility {
             /*
              * Accumulating negatively avoids surprises near MAX_VALUE
              */
-            digit = Character.digit(s.charAt(i++), RADIX);
+            digit = digit(s.charAt(i++));
             if (digit < 0) {
                 return DEFAULT;
             }
@@ -655,6 +655,33 @@ public final class FacebookMessagingUtility {
         return -result;
     }
 
+    private static int digit(final char c) {
+        switch (c) {
+        case '0':
+            return 0;
+        case '1':
+            return 1;
+        case '2':
+            return 2;
+        case '3':
+            return 3;
+        case '4':
+            return 4;
+        case '5':
+            return 5;
+        case '6':
+            return 6;
+        case '7':
+            return 7;
+        case '8':
+            return 8;
+        case '9':
+            return 9;
+        default:
+            return -1;
+        }
+    }
+
     private static final URLCodec URL_CODEC = new URLCodec(CharEncoding.UTF_8);
 
     /**
