@@ -185,12 +185,12 @@ public final class Utility {
         try {
             return future.get();
         } catch (final InterruptedException e) {
-            com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(Utility.class)).error(e.getMessage(), e);
+            org.slf4j.LoggerFactory.getLogger(Utility.class).error("", e);
             Thread.currentThread().interrupt();
             throw new IllegalStateException(e);
         } catch (final ExecutionException e) {
             final Throwable cause = e.getCause();
-            com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(Utility.class)).error(cause.getMessage(), cause);
+            org.slf4j.LoggerFactory.getLogger(Utility.class).error("", cause);
             return DEFAULT_MAIL_DATE_FORMAT;
         }
     }
