@@ -320,10 +320,8 @@ public final class InternalUtility {
         try {
             return Integer.parseInt(cl.substring('$' == cl.charAt(0) ? COLOR_LABEL_PREFIX.length() : COLOR_LABEL_PREFIX_OLD.length()));
         } catch (final NumberFormatException e) {
-            final org.apache.commons.logging.Log log = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(Utility.class));
-            if (log.isDebugEnabled()) {
-                log.debug("Inbvalid color label: " + cl, e);
-            }
+            final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(Utility.class);
+            log.debug("Inbvalid color label: {}", cl, e);
             return defaultValue;
         }
     }
