@@ -50,9 +50,7 @@
 package com.openexchange.messaging.rss.osgi;
 
 import javax.net.ssl.HttpsURLConnection;
-import org.apache.commons.logging.Log;
 import com.openexchange.html.HtmlService;
-import com.openexchange.log.LogFactory;
 import com.openexchange.messaging.MessagingService;
 import com.openexchange.messaging.rss.RSSMessagingService;
 import com.openexchange.osgi.HousekeepingActivator;
@@ -66,7 +64,7 @@ import com.openexchange.tools.ssl.TrustAllSSLSocketFactory;
  */
 public class Activator extends HousekeepingActivator {
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Activator.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Activator.class);
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -83,7 +81,7 @@ public class Activator extends HousekeepingActivator {
             registerService(MessagingService.class, new RSSMessagingService(), null);
             HttpsURLConnection.setDefaultSSLSocketFactory(TrustAllSSLSocketFactory.getDefault());
         } catch (final Exception x) {
-            LOG.error(x.getMessage(), x);
+            LOG.error("", x);
             throw x;
         }
     }
