@@ -49,12 +49,9 @@
 
 package com.openexchange.messaging.twitter.session;
 
-import java.text.MessageFormat;
 import java.util.Map;
-import org.apache.commons.logging.Log;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
-import com.openexchange.log.LogFactory;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondEventConstants;
 
@@ -65,9 +62,7 @@ import com.openexchange.sessiond.SessiondEventConstants;
  */
 public final class TwitterEventHandler implements EventHandler {
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(TwitterEventHandler.class));
-
-    private static final boolean DEBUG = LOG.isDebugEnabled();
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(TwitterEventHandler.class);
 
     public TwitterEventHandler() {
         super();
@@ -80,9 +75,8 @@ public final class TwitterEventHandler implements EventHandler {
             if (SessiondEventConstants.TOPIC_REMOVE_SESSION.equals(topic)) {
                 // A single session was removed
                 final Session session = (Session) event.getProperty(SessiondEventConstants.PROP_SESSION);
-                if (!session.isTransient() && TwitterAccessRegistry.getInstance().removeAccessIfLast(session.getContextId(), session.getUserId()) && DEBUG) {
-                    LOG.debug(new StringBuilder("Twitter access removed for user ").append(session.getUserId()).append(" in context ").append(
-                        session.getContextId()).toString());
+                if (!session.isTransient() && TwitterAccessRegistry.getInstance().removeAccessIfLast(session.getContextId(), session.getUserId())) {
+                    LOG.debug("Twitter access removed for user {} in context {}", session.getUserId(), session.getContextId());
                 }
             } else if (SessiondEventConstants.TOPIC_REMOVE_CONTAINER.equals(topic) || SessiondEventConstants.TOPIC_REMOVE_DATA.equals(topic)) {
                 // A session container was removed
@@ -91,17 +85,13 @@ public final class TwitterEventHandler implements EventHandler {
                 // For each session
                 final TwitterAccessRegistry accessRegistry = TwitterAccessRegistry.getInstance();
                 for (final Session session : sessionContainer.values()) {
-                    if (!session.isTransient() && accessRegistry.removeAccessIfLast(session.getContextId(), session.getUserId()) && DEBUG) {
-                        LOG.debug(new StringBuilder("Twitter access removed for user ").append(session.getUserId()).append(" in context ").append(
-                            session.getContextId()).toString());
+                    if (!session.isTransient() && accessRegistry.removeAccessIfLast(session.getContextId(), session.getUserId())) {
+                        LOG.debug("Twitter access removed for user {} in context {}", session.getUserId(), session.getContextId());
                     }
                 }
-            } else if (SessiondEventConstants.TOPIC_ADD_SESSION.equals(topic)) {
-                // final Session session = (Session) event.getProperty(SessiondEventConstants.PROP_SESSION);
-                // Nothing to do for an added session
             }
         } catch (final Exception e) {
-            LOG.error(MessageFormat.format("Error while handling SessionD event \"{0}\": {1}", topic, e.getMessage()), e);
+            LOG.error("Error while handling SessionD event \"{}\"", topic, e);
         }
     }
 }
