@@ -46,25 +46,29 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.rss;
 
 import java.util.Comparator;
 
-public class FeedByDateSorter<T> implements Comparator<RssResult>{
-	private final String order;
+/**
+ * {@link FeedByDateSorter} - The comparator for {@code RssResult}s.
+ */
+public class FeedByDateSorter implements Comparator<RssResult> {
 
-	public FeedByDateSorter(String order) {
-		this.order = order;
-	}
+    private final String order;
 
-	@Override
-	public int compare(RssResult r1, RssResult r2) {
-		int res = r1.getDate().compareTo(r2.getDate());
-		if(order.equalsIgnoreCase("DESC")) {
+    public FeedByDateSorter(String order) {
+        this.order = order;
+    }
+
+    @Override
+    public int compare(RssResult r1, RssResult r2) {
+        int res = r1.getDate().compareTo(r2.getDate());
+        if (order.equalsIgnoreCase("DESC")) {
             res *= -1;
         }
-		return res;
-	}
-
+        return res;
+    }
 
 }
