@@ -51,6 +51,7 @@ package com.openexchange.rss.osgi;
 
 import java.util.Dictionary;
 import java.util.Hashtable;
+import javax.net.ssl.HttpsURLConnection;
 import com.openexchange.ajax.requesthandler.ResultConverter;
 import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.capabilities.CapabilityChecker;
@@ -65,6 +66,7 @@ import com.openexchange.rss.actions.RssActionFactory;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
+import com.openexchange.tools.ssl.TrustAllSSLSocketFactory;
 
 public class RssActivator extends AJAXModuleActivator {
 
@@ -75,6 +77,7 @@ public class RssActivator extends AJAXModuleActivator {
 
     @Override
     protected void startBundle() {
+        HttpsURLConnection.setDefaultSSLSocketFactory(TrustAllSSLSocketFactory.getDefault());
         RssServices.LOOKUP.set(this);
         registerModule(new RssActionFactory(), "rss");
         registerService(ResultConverter.class, new RssJsonConverter());
